#juce is needed for plugins iem-suit
Name:	juce
Version:	7.0.6
Release:	%mkrel 1
URL:		https://github.com/juce-framework/JUCE/archive/refs/tags
Source0:	JUCE-%{version}.tar.xz
Source1:	juce_VSTInterface.h
Source2:	juce.png
Summary:	open-source cross-platform C++ application framework 
License:	(GPL3)
Group:	Editors

Obsoletes:	%{name}
Provides:	%{name}-%{version}-%{release}

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  doxygen
BuildRequires:  ladspa-devel
BuildRequires:  pkgconfig(fftw3) >= 3.3.5
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(lv2)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(x11)
BuildRequires:  freetype-devel
BuildRequires:  vst3sdk

Patch0:	juce-6.1.2-cmake_install.patch
Patch1:	juce-6.1.6-cmake_juce_utils.patch
Patch2:	juce-6.1.2-devendor_libs.patch
Patch4:	juce-6.1.2-projucer_disable_update_check.patch
Patch5:	juce-6.1.2-projucer_juce_paths.patch
Patch6:	juce-6.1.3-cmake_link_against_system_deps.patch

%description
JUCE is an open-source cross-platform C++ application framework for creating
high quality desktop and mobile applications, including VST, VST3, AU, AUv3, 
AAX and LV2 audio plug-ins and plug-in hosts. JUCE can be easily integrated 
with existing projects via CMake, or can be used as a project generation tool 
via the Projucer, which supports exporting projects for Xcode (macOS and iOS),
Visual Studio, Android Studio, Code::Blocks and Linux Makefiles as well as
containing a source code editor.

#------------------------------------------------------------------------------#
%package examples-Audio
Summary:	Juce-examples-Audio
Requires:	%{name}
Provides:	%{name}-examples-Audio
Group:	Editors

%description examples-Audio
AudioAppDemo AudioRecordingDemo MidiDemo SimpleFFTDemo AudioLatencyDemo
AudioSettingsDemo MPEDemo AudioPlaybackDemo AudioSynthesiserDemo
PluckedStringsDemo examples for projects build with Juce

%files examples-Audio
%{_datadir}/juce/examples/Audio/

#------------------------------------------------------------------------------#
%package example-DemoRunner
Summary:	Juce-example-DemoRunner
Requires:	%{name}
Provides:	%{name}-example-DemoRunner
%description example-DemoRunner
DemoRunner example for projects build with Juce

%files example-DemoRunner
%{_datadir}/juce/examples/DemoRunner/
#------------------------------------------------------------------------------#

%package examples-DSP
Summary:	Juce-examples-DSP
Requires:	%{name}
Provides:	%{name}-examples-DSP
Group:	Editors

%description examples-DSP
DSP examples for projects build with Juce

%files examples-DSP
%{_datadir}/juce/examples/DSP/
#------------------------------------------------------------------------------#

%package examples-GUI
Summary:	Juce-examples-GUI
Requires:	%{name}
Provides:	%{name}-examples-GUI
Group:	Editors

%description examples-GUI
GUI examples for projects build with Juce
%files examples-GUI
%{_datadir}/juce/examples/GUI/
#------------------------------------------------------------------------------#

%package examples-Plugins
Summary:	Juce-examples-Plugins
Requires:	%{name}
Provides:	%{name}-examples-Plugins
%description examples-Plugins
Plugins examples for projects build with Juce

%files examples-Plugins
%{_datadir}/juce/examples/Plugins/
#------------------------------------------------------------------------------#

%package examples-Utilities
Summary:	Juce-examples-Utilities
Requires:	%{name}
Provides:	%{name}-examples-Utilities
Group:	Editors
%description examples-Utilities
Utilities examples for projects build with Juce

%files examples-Utilities
%{_datadir}/juce/examples/Utilities/
#------------------------------------------------------------------------------#

%package doc
Summary:	All Doc's for Juce
Provides:	%{name}-Documents
AutoReqProv:no
Group:	Documentation

%description doc
Licenses and the HTML-Doc's for Juce
also the CMakeLists.txt for buildes

%files doc
%{_datadir}/doc/juce/BREAKING-CHANGES.txt
%{_datadir}/doc/juce/CMakeLists.txt
%{_datadir}/doc/juce/ChangeList.txt
%{_datadir}/doc/juce/box2d.Zlib.txt
%{_datadir}/doc/juce/glew.BSD-3-Clause.txt
%{_datadir}/doc/juce/khronos.MIT.txt
%{_datadir}/doc/juce/lv2.ISC.txt
%{_datadir}/doc/juce/mesa.MIT.txt
%{_datadir}/doc/juce/pslextensions.LicenseRef-Public-Domain.txt
%{_datadir}/doc/juce/html/
#------------------------------------------------------------------------------#

%prep
%setup -q -n JUCE-%{version}
find -type f -exec chmod 0644 {} \;

%autopatch -p1

rm -rvf modules/juce_audio_formats/codecs/flac/ \
    modules/juce_audio_formats/codecs/oggvorbis/ \
    modules/juce_audio_plugin_client/AU/ \
    modules/juce_graphics/image_formats/jpglib/ \
    modules/juce_graphics/image_formats/pnglib/ \
    modules/juce_core/zip/zlib/

%build
## extract licenses from vendored sources JUCE-%{version}/
sed -n '42,69p' modules/juce_opengl/opengl/juce_gl.h > glew.BSD-3-Clause.txt
sed -n '72,92p' modules/juce_opengl/opengl/juce_gl.h > mesa.MIT.txt
sed -n '95,114p' modules/juce_opengl/opengl/juce_gl.h > khronos.MIT.txt
sed -n '2,16p' modules/juce_box2d/box2d/Box2D.h > box2d.Zlib.txt
sed -n '3,8p' modules/juce_audio_processors/format_types/pslextensions/ipslcontextinfo.h > pslextensions.LicenseRef-Public-Domain.txt
cp -v modules/juce_audio_processors/format_types/LV2_SDK/lv2/COPYING lv2.ISC.txt

export VST3SDK="/usr/scr/vst3sdk"
export CFLAGS+=" -DNDEBUG"
export CXXFLAGS+=" -DNDEBUG"
export LDFLAGS+="$(pkg-config --libs libpng libjpeg flac vorbis vorbisfile vorbisenc ogg zlib)"

CFLAGS+=' -fcommon'
export LDFLAGS="-L/usr/lib64/libglvnd/ $LDFLAGS"

cmake -Bbuild -DCMAKE_BUILD_TYPE=None \
	-DCMAKE_INSTALL_PREFIX=/usr\
    -DJUCE_BUILD_EXTRAS=ON \
	-DJUCE_BUILD_EXAMPLES=ON \
	-DJUCE_TOOL_INSTALL_DIR=bin \
    -DJUCER_ENABLE_GPL_MODE="1" \
	-DCMAKE_SKIP_RPATH="ON" \
    -Wno-dev

cmake --build build --verbose

make -C docs/doxygen

%install
make DESTDIR=%{buildroot} VERBOSE=1 -C build install

## projucer has no install target
%__install -vDm 755 Projucer -t %{buildroot}/usr/bin/
# install custom vst2 handling from juce < 5.4.1
%__install -vDm 644 %{S:1} -t %{buildroot}/usr/share/juce/modules/juce_audio_processors/format_types/
# xdg desktop integration
###__install -vDm 644 *.desktop -t %{buildroot}/usr/share/applications/
# xdg desktop integration
mkdir -p %{buildroot}%{_datadir}/applications
cat <<EOF > %{buildroot}%{_datadir}/applications/com.juce_projucer.desktop
[Desktop Entry]
Name=Projucer
GenericName=Code manager and editor
Comment=Cross-platform project manager and C++ code editor for Plugins
Categories=X-MandrivaLinux-MoreApplications-Editors;GTK;Development;
Exec=Projucer
Icon=%{name}
StartupNotify=true
Terminal=false
Type=Application
EOF

# icons
%__install -d -m 0755 %{buildroot}%{_iconsdir}
%__install -vDm 644 examples/Assets/juce_icon.png %{buildroot}/usr/share/icons/hicolor/512x512/apps/Projucer.png
# and name.png
for i in 16 32 48 72 96 128 256; do
%__install -d -m 0755 %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps
%__install -m 0644 %{S:2} %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}.png
convert -resize ${i}x${i} %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}.png
done

# docs
%__install -vDm 644 ./*.txt -t %{buildroot}/usr/share/doc/%{name}/
%__install -d -m 0755 %{buildroot}/usr/share/doc/%{name}/html
%__cp -af %{_builddir}/JUCE-%{version}/docs/doxygen/doc/** %{buildroot}/usr/share/doc/%{name}/html/

# make examples and .h .cpp aviable in package demos ##
mkdir -p %{buildroot}%{_datadir}/juce/examples/{Audio,DemoRunner,DSP,GUI,Plugins,Utilities}
if [ -d %{_builddir}/JUCE-%{version}/build/examples ]; then
cd %{_builddir}/JUCE-%{version}/build/examples
for i in `find -type f -iname *Demo -o -iname *.h -o -iname *.cpp`; do
	dird=`echo $i | cut -d'/' -f2-3 | cut -d_ -f1`
	mkdir -p %{buildroot}%{_datadir}/juce/examples/$dird
	cp -f $i %{buildroot}%{_datadir}/juce/examples/$dird
done
fi

%post
gtk-update-icon-cache /usr/share/icons/hicolor/
/sbin/ldconfig
%update_menus

%postun
/sbin/ldconfig
%clean_menus

%files
%{_bindir}/JUCE-%{version}/juce_lv2_helper
%{_bindir}/JUCE-%{version}/juce_vst3_helper
%{_bindir}/Projucer
%{_bindir}/juceaide
%{_prefix}/lib/cmake/juce/
%{_datadir}/applications/com.juce_projucer.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/juce/modules/


%changelog
* Sat Mar 30 2024 onkelho <oh.quait at gmail.com> - 7.0.6-1quait2024
- rebuild and splitting
- new version released on Mar 26 2024
